summaryrefslogtreecommitdiffstats
path: root/tdehtml/dom/dom_node.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:54:26 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 15:54:26 -0600
commit7427e438358d44c37e3c8b0a9cfbb225ffd60e79 (patch)
treed977f1d23d324f23aadee0ad50acb94d7436ba80 /tdehtml/dom/dom_node.h
parent72eecb041bf15bf64b748fc062d55f6ec860ac60 (diff)
downloadtdelibs-7427e438358d44c37e3c8b0a9cfbb225ffd60e79.tar.gz
tdelibs-7427e438358d44c37e3c8b0a9cfbb225ffd60e79.zip
Rename KHTML and kiobuffer
Diffstat (limited to 'tdehtml/dom/dom_node.h')
-rw-r--r--tdehtml/dom/dom_node.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdehtml/dom/dom_node.h b/tdehtml/dom/dom_node.h
index 594aa5e3e..b87997547 100644
--- a/tdehtml/dom/dom_node.h
+++ b/tdehtml/dom/dom_node.h
@@ -63,7 +63,7 @@ class Event;
* imply that the DOM specifies an order to these Nodes.
*
*/
-class KHTML_EXPORT NamedNodeMap
+class TDEHTML_EXPORT NamedNodeMap
{
public:
NamedNodeMap();
@@ -271,7 +271,7 @@ class NodeImpl;
* mechanisms to get and set the relevant information.
*
*/
-class KHTML_EXPORT Node
+class TDEHTML_EXPORT Node
{
friend class NamedNodeMap;
friend class NodeList;
@@ -775,7 +775,7 @@ public:
*
* @exception DOMException
* NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
* Note: KHTML will also raise this if setContent is called on things
* that do not have child nodes.
*
* @since 3.5.7
@@ -928,7 +928,7 @@ class NodeListImpl;
* integral index, starting from 0.
*
*/
-class KHTML_EXPORT NodeList
+class TDEHTML_EXPORT NodeList
{
friend class Element;
friend class Node;
@@ -775,7 +775,7 @@ public:
* @exception DOMException
* NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
- * Note: KHTML will also raise this if setContent is called on things
+ * Note: TDEHTML will also raise this if setContent is called on things
* that do not have child nodes.
*